pub struct AwsJsonRpcProtocol { /* private fields */ }Expand description
AWS JSON RPC protocol (awsJson1_0 / awsJson1_1).
Implementations
Sourceimpl AwsJsonRpcProtocol
impl AwsJsonRpcProtocol
Sourcepub fn aws_json_1_0(target_prefix: impl Into<String>) -> Self
pub fn aws_json_1_0(target_prefix: impl Into<String>) -> Self
Creates an AWS JSON 1.0 protocol instance.
target_prefix is the Smithy service shape name used in the X-Amz-Target header
(e.g., "TrentService" for KMS, "DynamoDB_20120810" for DynamoDB).
Sourcepub fn aws_json_1_1(target_prefix: impl Into<String>) -> Self
pub fn aws_json_1_1(target_prefix: impl Into<String>) -> Self
Creates an AWS JSON 1.1 protocol instance.
target_prefix is the Smithy service shape name used in the X-Amz-Target header.